@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * fn-logical.c:  Built in logical functions and functions registration
  *
@@ -403,42 +402,42 @@ gnumeric_false (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 
 GnmFuncDescriptor const logical_functions[] = {
 	{ "and", NULL,  help_and, NULL,
-	  gnumeric_and, NULL, NULL,
+	  gnumeric_and,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "or", NULL,  help_or, NULL,
-	  gnumeric_or, NULL, NULL,
+	  gnumeric_or, 
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "not", "b",  help_not, gnumeric_not,
-	  NULL, NULL, NULL,
+	  NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "iferror", "EE",  help_iferror,
-	  gnumeric_iferror, NULL, NULL, NULL,
+	  gnumeric_iferror, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_SECOND,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "ifna", "EE",  help_ifna,
-	  gnumeric_ifna, NULL, NULL, NULL,
+	  gnumeric_ifna, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_SECOND,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC,
 	  GNM_FUNC_TEST_STATUS_NO_TESTSUITE},
 	{ "ifs", NULL,  help_ifs,
-	  NULL, gnumeric_ifs, NULL, NULL,
+	  NULL, gnumeric_ifs,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "switch", NULL,  help_switch,
-	  NULL, gnumeric_switch, NULL, NULL,
+	  NULL, gnumeric_switch,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "true", "", help_true, gnumeric_true,
-	  NULL, NULL, NULL,
+	  NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "false", "", help_false, gnumeric_false,
-	  NULL, NULL, NULL,
+	  NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "xor", NULL,  help_xor, NULL,
-	  gnumeric_xor, NULL, NULL,
+	  gnumeric_xor,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_UNITLESS,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_BASIC },
         {NULL}
