@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * python-loader.c: Support for Python plugins.
  *
@@ -12,17 +11,17 @@
 #include "py-gnumeric.h"
 #include "gnm-python.h"
 
-#include "gnm-plugin.h"
-#include "application.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "workbook-view.h"
-#include "wbc-gtk.h"
-#include "gui-util.h"
-#include "value.h"
-#include "expr.h"
-#include "expr-impl.h"
-#include "func.h"
+#include <gnm-plugin.h>
+#include <application.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <workbook-view.h>
+#include <wbc-gtk.h>
+#include <gui-util.h>
+#include <value.h>
+#include <expr.h>
+#include <expr-impl.h>
+#include <func.h>
 
 #include <goffice/goffice.h>
 #include <goffice/app/module-plugin-defs.h>
@@ -37,6 +36,8 @@
 #include <Python.h>
 #include <pygobject.h>
 
+#define SERVICE_KEY "python-loader::service"
+
 typedef struct {
 	GObject base;
 
@@ -463,7 +464,7 @@ call_python_function_args (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 	ServiceLoaderDataFunctionGroup *loader_data;
 	PyObject *fn_info_tuple;
 	PyObject *python_fn;
-	GnmFunc const * fndef;
+	GnmFunc *fndef;
 
 	gint min_n_args, max_n_args, n_args;
 
@@ -472,7 +473,7 @@ call_python_function_args (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 	g_return_val_if_fail (args != NULL, NULL);
 
 	fndef = ei->func_call->func;
-	service = (GOPluginService *) gnm_func_get_user_data (fndef);
+	service = (GOPluginService *)g_object_get_data (G_OBJECT (fndef), SERVICE_KEY);
 	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
 	SWITCH_TO_PLUGIN (go_plugin_service_get_plugin (service));
 	fn_info_tuple = PyDict_GetItemString (loader_data->python_fn_info_dict,
@@ -502,7 +503,7 @@ call_python_function_nodes (GnmFuncEvalInfo *ei,
 	g_return_val_if_fail (ei->func_call != NULL, NULL);
 
 	fndef = ei->func_call->func;
-	service = (GOPluginService *) gnm_func_get_user_data (fndef);
+	service = (GOPluginService *)g_object_get_data (G_OBJECT (fndef), SERVICE_KEY);
 	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
 	SWITCH_TO_PLUGIN (go_plugin_service_get_plugin (service));
 	python_fn = PyDict_GetItemString (loader_data->python_fn_info_dict,
@@ -644,24 +645,25 @@ python_function_get_gnumeric_help (PyObject *python_fn_info_dict, PyObject *pyth
 	return (GnmFuncHelp const *) PyCObject_AsVoidPtr (cobject_help_value);
 }
 
-static gboolean
-gplp_func_desc_load (GOPluginService *service,
-		     char const *name,
-		     GnmFuncDescriptor *res)
+static void
+gplp_func_load_stub (GOPluginService *service,
+		     GnmFunc *func)
 {
 	ServiceLoaderDataFunctionGroup *loader_data;
 	PyObject *fn_info_obj;
+	char const *name;
 
-	g_return_val_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service), FALSE);
-	g_return_val_if_fail (name != NULL, FALSE);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
+	g_return_if_fail (GNM_IS_FUNC (func));
 
+	name = gnm_func_get_name (func, FALSE);
 	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
 	SWITCH_TO_PLUGIN (go_plugin_service_get_plugin (service));
 	fn_info_obj = PyDict_GetItemString (loader_data->python_fn_info_dict,
-					    (gchar *) name);
+					    (gchar *)name);
 	if (fn_info_obj == NULL) {
 		gnm_python_clear_error_if_needed (SERVICE_GET_LOADER (service)->py_object);
-		return FALSE;
+		return;
 	}
 
 	if (PyTuple_Check (fn_info_obj)) {
@@ -673,35 +675,31 @@ gplp_func_desc_load (GOPluginService *service,
 			PyString_Check (python_args) &&
 		    (python_fn = PyTuple_GetItem (fn_info_obj, 2)) != NULL &&
 		    PyCallable_Check (python_fn)) {
-			res->arg_spec	= PyString_AsString (python_args);
-			res->help	= python_function_get_gnumeric_help (
-				loader_data->python_fn_info_dict, python_fn, name);
-			res->fn_args	= &call_python_function_args;
-			res->fn_nodes	= NULL;
-			res->linker	= NULL;
-			res->impl_status = GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC;
-			res->test_status = GNM_FUNC_TEST_STATUS_UNKNOWN;
-			return TRUE;
+			GnmFuncHelp const *help = python_function_get_gnumeric_help 
+				(loader_data->python_fn_info_dict, python_fn, name);
+			gnm_func_set_fixargs (func, call_python_function_args, PyString_AsString (python_args));
+			gnm_func_set_help (func, help, -1);
+			gnm_func_set_impl_status (func, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC);
+			g_object_set_data (G_OBJECT (func), SERVICE_KEY, service);
+			return;
 		}
 
 		gnm_python_clear_error_if_needed (SERVICE_GET_LOADER (service)->py_object);
-		return FALSE;
+		return;
 	}
 
 	if (PyCallable_Check (fn_info_obj)) {
-		res->arg_spec	= "";
-		res->help	= python_function_get_gnumeric_help (
-			loader_data->python_fn_info_dict, fn_info_obj, name);
-		res->fn_args	= NULL;
-		res->fn_nodes	= &call_python_function_nodes;
-		res->linker	= NULL;
-		res->impl_status = GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC;
-		res->test_status = GNM_FUNC_TEST_STATUS_UNKNOWN;
-		return TRUE;
+		GnmFuncHelp const *help = python_function_get_gnumeric_help
+			(loader_data->python_fn_info_dict, fn_info_obj, name);
+		gnm_func_set_varargs (func, call_python_function_nodes, NULL);
+		gnm_func_set_help (func, help, -1);
+		gnm_func_set_impl_status (func, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC);
+		g_object_set_data (G_OBJECT (func), SERVICE_KEY, service);
+		return;
 	}
 
 	gnm_python_clear_error_if_needed (SERVICE_GET_LOADER (service)->py_object);
-	return FALSE;
+	return;
 }
 
 static void
@@ -727,7 +725,7 @@ gplp_load_service_function_group (GOPluginLoader *loader,
 		ServiceLoaderDataFunctionGroup *loader_data;
 
 		cbs = go_plugin_service_get_cbs (service);
-		cbs->func_desc_load = &gplp_func_desc_load;
+		cbs->load_stub = &gplp_func_load_stub;
 
 		loader_data = g_new (ServiceLoaderDataFunctionGroup, 1);
 		loader_data->python_fn_info_dict = (PyObject *) python_fn_info_dict;
