@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dependent.c:  Manage calculation dependencies between objects
  *
@@ -21,22 +20,22 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "dependent.h"
+#include <gnumeric.h>
+#include <dependent.h>
 
-#include "workbook-priv.h"
-#include "value.h"
-#include "cell.h"
-#include "sheet.h"
-#include "expr.h"
-#include "expr-impl.h"
-#include "expr-name.h"
-#include "application.h"
-#include "workbook-view.h"
-#include "ranges.h"
-#include "gutils.h"
-#include "sheet-view.h"
-#include "func.h"
+#include <workbook-priv.h>
+#include <value.h>
+#include <cell.h>
+#include <sheet.h>
+#include <expr.h>
+#include <expr-impl.h>
+#include <expr-name.h>
+#include <application.h>
+#include <workbook-view.h>
+#include <ranges.h>
+#include <gutils.h>
+#include <sheet-view.h>
+#include <func.h>
 
 #include <goffice/goffice.h>
 #include <string.h>
@@ -134,7 +133,7 @@ cset_insert (CSet **list, gpointer datum)
 		cs->data[cs->count++] = datum;
 }
 
-/* NOTE: takes reference.  Returns TRUE if datum was already present.  */
+/* NOTE: takes reference.  Returns %TRUE if datum was already present.  */
 static gboolean
 cset_insert_checked (CSet **list, gpointer datum)
 {
@@ -159,7 +158,7 @@ cset_insert_checked (CSet **list, gpointer datum)
 }
 
 
-/* NOTE: takes reference.  Returns TRUE if removed.  */
+/* NOTE: takes reference.  Returns %TRUE if removed.  */
 static gboolean
 cset_remove (CSet **list, gpointer datum)
 {
@@ -1112,15 +1111,14 @@ link_unlink_expr_dep (GnmEvalPos *ep, GnmExpr const *tree, gboolean qlink)
 	 */
 	case GNM_EXPR_OP_FUNCALL: {
 		int i;
-		GnmDependentFlags flag = DEPENDENT_NO_FLAG;
-		if (tree->func.func->fn_type == GNM_FUNC_TYPE_STUB)
-			gnm_func_load_stub (tree->func.func);
-		if (tree->func.func->linker) {
-			GnmFuncEvalInfo fei;
-			fei.pos = ep;
-			fei.func_call = &tree->func;
-			flag = tree->func.func->linker (&fei, qlink);
-		}
+		GnmFuncEvalInfo fei;
+		GnmDependentFlags flag;
+
+		gnm_func_load_if_stub (tree->func.func);
+		fei.pos = ep;
+		fei.func_call = &tree->func;
+		flag = gnm_func_link_dep (tree->func.func, &fei, qlink);
+
 		if (!(flag & DEPENDENT_IGNORE_ARGS))
 			for (i = 0; i < tree->func.argc; i++)
 				flag |= link_unlink_expr_dep (ep, tree->func.argv[i], qlink);
