@@ -3,11 +3,11 @@
 #define _BSD_SOURCE 1
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "gnm-random.h"
-#include "mathfunc.h"
-#include "sf-dpq.h"
-#include "sf-gamma.h"
+#include <gnumeric.h>
+#include <gnm-random.h>
+#include <mathfunc.h>
+#include <sf-dpq.h>
+#include <sf-gamma.h>
 #include <glib/gstdio.h>
 #ifdef G_OS_WIN32
 #include <windows.h>
@@ -409,8 +409,11 @@ random_01 (void)
 }
 
 /* ------------------------------------------------------------------------ */
-/*
- * Generate a N(0,1) distributed number.
+
+/**
+ * random_normal:
+ *
+ * Returns: a N(0,1) distributed random number.
  */
 gnm_float
 random_normal (void)
