@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gnumeric-util.c:  Various GUI utility functions.
  *
@@ -8,25 +7,24 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "libgnumeric.h"
-#include "gui-util.h"
+#include <gnumeric.h>
+#include <libgnumeric.h>
+#include <gui-util.h>
 
-#include "gutils.h"
-#include "parse-util.h"
-#include "style.h"
-#include "style-color.h"
-#include "value.h"
-#include "number-match.h"
-#include "gnm-format.h"
-#include "application.h"
-#include "workbook.h"
-#include "libgnumeric.h"
-#include "wbc-gtk.h"
-#include "widgets/gnumeric-expr-entry.h"
+#include <gutils.h>
+#include <parse-util.h>
+#include <style.h>
+#include <style-color.h>
+#include <value.h>
+#include <number-match.h>
+#include <gnm-format.h>
+#include <application.h>
+#include <workbook.h>
+#include <libgnumeric.h>
+#include <wbc-gtk.h>
+#include <widgets/gnm-expr-entry.h>
 
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
 #include <atk/atkrelation.h>
 #include <atk/atkrelationset.h>
 #include <gdk/gdkkeysyms.h>
@@ -341,7 +339,8 @@ gnm_keyed_dialog (WBCGtk *wbcg, GtkWindow *dialog, char const *key)
  * @key:     A key to identify the dialog
  *
  * Raise the dialog identified by key if it is registered on the wbcg.
- * Returns: (transfer none): TRUE if dialog found, FALSE if not.
+ *
+ * Returns: (transfer none) (type GtkDialog) (nullable): existing dialog
  **/
 gpointer
 gnm_dialog_raise_if_exists (WBCGtk *wbcg, char const *key)
@@ -462,9 +461,9 @@ kill_popup_menu (GtkWidget *widget, G_GNUC_UNUSED gpointer user)
 /**
  * gnumeric_popup_menu:
  * @menu: #GtkMenu
- * @event: #GdkEvent optionally NULL
+ * @event: (nullable): #GdkEvent
  *
- * Bring up a popup and if @event is non-NULL ensure that the popup is on the
+ * Bring up a popup and if @event is non-%NULL ensure that the popup is on the
  * right screen.
  **/
 void
@@ -584,7 +583,11 @@ gnm_gtk_builder_load (char const *uifile, char const *domain, GOCmdContext *cc)
 	GtkBuilder *gui;
 	char *f;
 
-	if (g_path_is_absolute (uifile)) {
+	if (strncmp (uifile, "res:", 4) == 0) {
+		f = g_strconcat ("res:/org/gnumeric/gnumeric/",
+				 uifile + 4,
+				 NULL);
+	} else if (g_path_is_absolute (uifile)) {
 		f = g_strdup (uifile);
 	} else {
 		f = g_strconcat ("res:gnm:", uifile, NULL);
@@ -597,14 +600,28 @@ gnm_gtk_builder_load (char const *uifile, char const *domain, GOCmdContext *cc)
 }
 
 static void
-popup_item_activate (GtkWidget *item, gpointer *user_data)
+popup_item_activate (GtkWidget *item, GnmPopupMenuElement const *elem)
 {
-	GnmPopupMenuElement const *elem =
-		g_object_get_data (G_OBJECT (item), "descriptor");
-	GnmPopupMenuHandler handler =
-		g_object_get_data (G_OBJECT (item), "handler");
+	GtkWidget *menu;
+	GnmPopupMenuHandler handler;
+	gpointer user_data;
 
-	g_return_if_fail (elem != NULL);
+	// Go to top-level menu.  This shouldn't be that hard.
+	menu = item;
+	while (TRUE) {
+		if (GTK_IS_MENU_ITEM (menu))
+			menu = gtk_widget_get_parent (menu);
+		else if (GTK_IS_MENU (menu)) {
+			GtkWidget *a = gtk_menu_get_attach_widget (GTK_MENU (menu));
+			if (a)
+				menu = a;
+			else
+				break;
+		} else
+			break;
+	}
+	handler = g_object_get_data (G_OBJECT (menu), "handler");
+	user_data = g_object_get_data (G_OBJECT (menu), "user-data");
 	g_return_if_fail (handler != NULL);
 
 	handler (elem, user_data);
@@ -613,24 +630,28 @@ popup_item_activate (GtkWidget *item, gpointer *user_data)
 /**
  * gnm_create_popup_menu:
  * @elements:
- * @handler: (scope async):
+ * @handler: (scope notified):
  * @user_data: user data to pass to @handler.
+ * @notify: destroy notification for @user_data
  * @display_filter:
  * @sensitive_filter:
  * @event:
  **/
 void
 gnm_create_popup_menu (GnmPopupMenuElement const *elements,
-			    GnmPopupMenuHandler handler,
-			    gpointer user_data,
-			    int display_filter, int sensitive_filter,
-			    GdkEvent *event)
+		       GnmPopupMenuHandler handler,
+		       gpointer user_data,
+		       GDestroyNotify notify,
+		       int display_filter, int sensitive_filter,
+		       GdkEvent *event)
 {
 	char const *trans;
 	GSList *menu_stack = NULL;
 	GtkWidget *menu, *item;
 
 	menu = gtk_menu_new ();
+	g_object_set_data (G_OBJECT (menu), "handler", (gpointer)handler);
+	g_object_set_data_full (G_OBJECT (menu), "user-data", user_data, notify);
 	for (; NULL != elements->name ; elements++) {
 		char const * const name = elements->name;
 		char const * const pix_name = elements->pixmap;
@@ -675,12 +696,9 @@ gnm_create_popup_menu (GnmPopupMenuElement const *elements,
 
 		if (elements->index > 0) {
 			g_signal_connect (G_OBJECT (item),
-				"activate",
-				G_CALLBACK (&popup_item_activate), user_data);
-			g_object_set_data (
-				G_OBJECT (item), "descriptor", (gpointer)(elements));
-			g_object_set_data (
-				G_OBJECT (item), "handler", (gpointer)handler);
+					  "activate",
+					  G_CALLBACK (popup_item_activate),
+					  (gpointer)elements);
 		}
 		if (NULL != item) {
 			gtk_widget_show (item);
@@ -1359,4 +1377,11 @@ gnm_style_context_get_color (GtkStyleContext *context,
 	gtk_style_context_restore (context);
 }
 
+void
+gnm_get_link_color (GtkWidget *widget, GdkRGBA *res)
+{
+	GtkStyleContext *ctxt = gtk_widget_get_style_context (widget);
+	gnm_style_context_get_color (ctxt, GTK_STATE_FLAG_LINK, res);
+}
+
 // ----------------------------------------------------------------------------
