@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * hlink.c: hyperlink support
@@ -22,22 +21,22 @@
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "hlink.h"
-#include "hlink-impl.h"
-#include "command-context.h"
-#include "workbook-control.h"
-#include "workbook-view.h"
-#include "selection.h"
-#include "sheet.h"
-#include "sheet-view.h"
-#include "sheet-style.h"
-#include "ranges.h"
-#include "position.h"
-#include "expr-name.h"
-#include "expr.h"
-#include "value.h"
-#include "mstyle.h"
+#include <gnumeric.h>
+#include <hlink.h>
+#include <hlink-impl.h>
+#include <command-context.h>
+#include <workbook-control.h>
+#include <workbook-view.h>
+#include <selection.h>
+#include <sheet.h>
+#include <sheet-view.h>
+#include <sheet-style.h>
+#include <ranges.h>
+#include <position.h>
+#include <expr-name.h>
+#include <expr.h>
+#include <value.h>
+#include <mstyle.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
@@ -53,10 +52,10 @@ static GObjectClass *gnm_hlink_parent_class;
  */
 /**
  * gnm_hlink_activate:
- * @lnk:
+ * @lnk: #GnmHLink
  * @wbcg: the wbcg that activated the link
  *
- * Returns: TRUE if the link successfully activated.
+ * Returns: %TRUE if the link successfully activated.
  **/
 gboolean
 gnm_hlink_activate (GnmHLink *lnk, WBCGtk *wbcg)
@@ -71,7 +70,7 @@ gnm_hlink_activate (GnmHLink *lnk, WBCGtk *wbcg)
  * @sheet: #Sheet
  * @pos: #GcmCellPos
  *
- * Returns: (transfer none): the found #GnmHLink.
+ * Returns: (transfer none) (nullable): the found #GnmHLink.
  **/
 GnmHLink *
 gnm_sheet_hlink_find (Sheet const *sheet, GnmCellPos const *pos)
@@ -138,6 +137,12 @@ gnm_hlink_init (GObject *obj)
 GSF_CLASS_ABSTRACT (GnmHLink, gnm_hlink,
 		    gnm_hlink_class_init, gnm_hlink_init, G_TYPE_OBJECT)
 
+/**
+ * gnm_hlink_get_target:
+ * @lnk: #GnmHLink
+ *
+ * Returns: (transfer none): @lnk's target.
+ */
 const char *
 gnm_hlink_get_target (GnmHLink const *lnk)
 {
@@ -154,6 +159,12 @@ gnm_hlink_set_target (GnmHLink *lnk, gchar const *target)
 	GET_CLASS (lnk)->set_target (lnk, target);
 }
 
+/**
+ * gnm_hlink_get_tip:
+ * @lnk: #GnmHLink
+ *
+ * Returns: (transfer none): @lnk's tooltip.
+ */
 const char *
 gnm_hlink_get_tip (GnmHLink const *lnk)
 {
@@ -175,7 +186,7 @@ gnm_hlink_set_tip (GnmHLink *lnk, gchar const *tip)
 
 /**
  * gnm_hlink_get_sheet:
- * @lnk: link
+ * @lnk: #GnmHLink
  *
  * Returns: (transfer none): the sheet
  */
@@ -400,7 +411,7 @@ GSF_CLASS (GnmHLinkCurWB, gnm_hlink_cur_wb,
 /**
  * gnm_hlink_get_range_target:
  * @lnk: the hyperlink to query
- * @sr: location to start link target range
+ * @sr: (out): location to store link target range
  *
  * This function determines the location that a link points to.  It will
  * resolve names.
@@ -417,6 +428,8 @@ gnm_hlink_get_range_target (GnmHLink const *lnk, GnmSheetRange *sr)
 	GnmParsePos pp;
 	Sheet *start_sheet, *end_sheet;
 
+	memset (sr, 0, sizeof (*sr));
+
 	g_return_val_if_fail (GNM_IS_HLINK (lnk), FALSE);
 
 	if (!GNM_IS_HLINK_CUR_WB (lnk))
@@ -441,6 +454,14 @@ gnm_hlink_get_range_target (GnmHLink const *lnk, GnmSheetRange *sr)
 }
 
 
+/**
+ * gnm_hlink_get_target_expr:
+ * @lnk: the hyperlink to query
+ *
+ * This function determines the location that a link points to.
+ *
+ * Returns: (transfer none) (nullable): A #GnmExprTop describing the target.
+ */
 GnmExprTop const *
 gnm_hlink_get_target_expr (GnmHLink const *lnk)
 {
@@ -558,10 +579,10 @@ GSF_CLASS (GnmHLinkExternal, gnm_hlink_external,
 	   GNM_HLINK_TYPE)
 
 /**
- * _gnm_hlink_init: (skip)
+ * gnm_hlink_init_: (skip)
  */
 void
-_gnm_hlink_init (void)
+gnm_hlink_init_ (void)
 {
 	/* make sure that all hlink types are registered */
 	gnm_hlink_cur_wb_get_type ();
