@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_PREVIEW_GRID_IMPL_H_
 #define _GNM_PREVIEW_GRID_IMPL_H_
 
-#include "preview-grid.h"
+#include <preview-grid.h>
 #include <goffice/goffice.h>
 
 G_BEGIN_DECLS
