@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * workbook-view.c: View functions for the workbook
  *
@@ -21,46 +20,46 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "workbook-view.h"
+#include <gnumeric.h>
+#include <workbook-view.h>
 
-#include "workbook-control-priv.h"
-#include "workbook-priv.h"
-#include "application.h"
-#include "sheet.h"
-#include "sheet-view.h"
-#include "sheet-merge.h"
-#include "sheet-style.h"
-#include "func.h"
-#include "expr.h"
-#include "expr-name.h"
-#include "value.h"
-#include "ranges.h"
-#include "selection.h"
-#include "mstyle.h"
-#include "validation.h"
-#include "validation-combo.h"
-#include "gnm-sheet-slicer.h"
-#include "gnm-sheet-slicer-combo.h"
-#include "position.h"
-#include "cell.h"
-#include "gutils.h"
-#include "command-context.h"
-#include "auto-format.h"
-#include "sheet-object.h"
-#include "gnumeric-conf.h"
+#include <workbook-control-priv.h>
+#include <workbook-priv.h>
+#include <application.h>
+#include <sheet.h>
+#include <sheet-view.h>
+#include <sheet-merge.h>
+#include <sheet-style.h>
+#include <func.h>
+#include <expr.h>
+#include <expr-name.h>
+#include <value.h>
+#include <ranges.h>
+#include <selection.h>
+#include <mstyle.h>
+#include <validation.h>
+#include <validation-combo.h>
+#include <gnm-sheet-slicer.h>
+#include <gnm-sheet-slicer-combo.h>
+#include <position.h>
+#include <cell.h>
+#include <gutils.h>
+#include <command-context.h>
+#include <auto-format.h>
+#include <sheet-object.h>
+#include <gnumeric-conf.h>
 
 #include <goffice/goffice.h>
 #include <gsf/gsf-meta-names.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-input.h>
-#include "gnm-i18n.h"
+#include <gnm-i18n.h>
 #include <glib/gstdio.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include "mathfunc.h"
+#include <mathfunc.h>
 
 #ifdef G_OS_WIN32
 #include <windows.h>
@@ -615,10 +614,10 @@ wb_view_auto_expr_func (WorkbookView *wbv, GnmFunc *func)
 		return;
 
 	if (wbv->auto_expr.func)
-		gnm_func_unref (wbv->auto_expr.func);
+		gnm_func_dec_usage (wbv->auto_expr.func);
 
 	if (func)
-		gnm_func_ref (func);
+		gnm_func_inc_usage (func);
 	wbv->auto_expr.func = func;
 
 	wb_view_auto_expr_recalc (wbv);
@@ -906,16 +905,15 @@ workbook_view_class_init (GObjectClass *gobject_class)
 	gobject_class->get_property = wb_view_get_property;
 	gobject_class->dispose = wb_view_dispose;
 
-	/* FIXME?  Make a boxed type.  */
         g_object_class_install_property
 		(gobject_class,
 		 PROP_AUTO_EXPR_FUNC,
-		 g_param_spec_boxed ("auto-expr-func",
-				     P_("Auto-expression function"),
-				     P_("The automatically computed sheet function."),
-				     gnm_func_get_type (),
-				     GSF_PARAM_STATIC |
-				     G_PARAM_READWRITE));
+		 g_param_spec_object ("auto-expr-func",
+				      P_("Auto-expression function"),
+				      P_("The automatically computed sheet function."),
+				      GNM_FUNC_TYPE,
+				      GSF_PARAM_STATIC |
+				      G_PARAM_READWRITE));
         g_object_class_install_property
 		(gobject_class,
 		 PROP_AUTO_EXPR_DESCR,
