@@ -1,11 +1,10 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_WORKBOOK_H_
 # define _GNM_WORKBOOK_H_
 
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <goffice/goffice.h>
 #include <glib-object.h>
-#include "gui-file.h"
+#include <gui-file.h>
 
 G_BEGIN_DECLS
 
